@@ -79,18 +79,18 @@ def printc(s: str, col: Ansi_T, end: str = '\n') -> None:
     stdout_write(f'{col!r}{s}{_reset}{end}')
     stdout_flush()
 
-_log_tz = ZoneInfo('America/Toronto') # default
+_log_tz = ZoneInfo('GMT') # default
 def set_timezone(tz: tzinfo) -> None:
     global _log_tz
     _log_tz = tz
 
 def log(msg: str, col: Optional[Ansi_T] = None,
-        fd: Optional[str] = None, end: str = '\n') -> None:
+        file: Optional[str] = None, end: str = '\n') -> None:
     """\
     Print a string, in a specified ansi colour with timestamp.
 
     Allows for the functionality to write to a file as
-    well by passing the filepath with the `fd` parameter.
+    well by passing the filepath with the `file` parameter.
     """
 
     ts_short = get_timestamp(full=False, tz=_log_tz)
@@ -102,7 +102,7 @@ def log(msg: str, col: Optional[Ansi_T] = None,
 
     stdout_flush()
 
-    if fd:
-        # log simple ascii output to fd.
-        with open(fd, 'a+') as f:
+    if file:
+        # log simple ascii output to file.
+        with open(file, 'a+') as f:
             f.write(f'[{get_timestamp(full=True, tz=_log_tz)}] {msg}\n')
