@@ -14,6 +14,7 @@ import select
 import signal
 import socket
 import sys
+import urllib.parse
 from functools import wraps
 from time import perf_counter as clock
 from time import perf_counter_ns as clock_ns
@@ -166,10 +167,10 @@ class Connection:
         self.raw_path = None
         self.httpver = 0.0
 
-        self.args = {}
-        self.multipart_args = {}
+        self.args: dict[str, str] = {}
+        self.multipart_args: dict[str, str] = {}
 
-        self.files = {}
+        self.files: dict[str, bytes] = {}
 
         # Response params
         self.resp_code = 200
@@ -179,7 +180,7 @@ class Connection:
 
     """ Request methods """
 
-    def _parse_urlencoded(self, data: bytes) -> None:
+    def _parse_urlencoded(self, data: str) -> None:
         for a_pair in data.split('&'):
             a_key, a_val = a_pair.split('=', 1)
             self.args[a_key] = a_val
@@ -269,7 +270,9 @@ class Connection:
                 if content_type.startswith('multipart/form-data'):
                     self._parse_multipart()
                 elif content_type == 'application/x-www-form-urlencoded':
-                    self._parse_urlencoded(self.body.obj) # hmmm
+                    self._parse_urlencoded(
+                        urllib.parse.unquote(self.body.tobytes().decode())
+                    ) # hmmm
 
     """ Response methods """
 
@@ -608,7 +611,7 @@ class Server:
                 await self.before_serving()
 
             # Start pending coroutine tasks.
-            if self.debug:
+            if self.debug and self._task_coros:
                 log(f'-> Starting {len(self._task_coros)} tasks.', Ansi.LMAGENTA)
 
             for coro in self._task_coros:
